@@ -37,15 +37,17 @@ main_globals = Globals()
 @click.option('--show', is_flag=True, help='Show the resulting bitmap in the system viewer.')
 @click.option('--shift-x', default=0, help='Shift along horizontal axis in the bitmap.', type=int)
 @click.option('--shift-y', default=0, help='Shift along vertical axis in the bitmap.', type=int)
-@click.option('--color-background', default='black', help='Background color.', type=str)
-@click.option('--color-characters', default='white', help='Color of characters.', type=str)
+@click.option('--image-mode', default='RGBA', help='Image mode for the pillow package.)', type=str)
+@click.option('--color-background', default='#00000000', help='Background color.', type=str)
+@click.option('--color-characters', default='#ffffffff', help='Color of characters.', type=str)
 @click.option('--encoding', default='iso-8859-1', help='Encoding of the bitmap.', type=str)
-@click.option('--is-ang-at00', default=False, is_flag=True, help='Å symbol at position (0,0)')
+@click.option('--is-ang-at00', default=False, is_flag=True, help='Put Å symbol at position (0,0).')
 def main(font_file_name: str,
          size: int,
          show: bool,
          shift_x: int,
          shift_y: int,
+         image_mode: str,
          color_background: str,
          color_characters: str,
          encoding: str,
@@ -60,9 +62,12 @@ def main(font_file_name: str,
         show: True to show the generated bitmap, False otherwise.
         shift_x: a rigid shift along horizontal axis in the resulting bitmap.
         shift_y: a rigid shift along vertical axis in the resulting bitmap.
-        color_background: the background color of the bitmap, e.g. red or #ff0000
-        color_characters: the color of the characters in the resulting bitmap, e.g. white, #ffffff
-        encoding: iso-8859-7, cp737, cp869 etc:
+        image_mode: type of color encoding according to pillow package,
+                    e.g. RGB, RGBA, LA, L, P. For a full list of options, have a look
+                    https://pillow.readthedocs.io/en/stable/handbook/concepts.html#concept-modes
+        color_background: the background color of the bitmap, e.g. #ff000000 (red)
+        color_characters: the color of the characters in the resulting bitmap, #ffffffff (white)
+        encoding: iso-8859-7, cp737, cp869 etc. For a full list of encodings, have a look
                   https://docs.python.org/3/library/codecs.html#standard-encodings
         is_ang_at00: Å symbol at position (0,0)
     """
@@ -73,6 +78,8 @@ def main(font_file_name: str,
     click.secho(f'font_file_name: {font_file_name}')
     click.secho(f'size: {size}')
     click.secho(f'char_size: {char_size}')
+    click.secho(f'color_background: {color_background}')
+    click.secho(f'color_characters: {color_characters}')
 
     symbols = get_symbols(encoding)
 
@@ -82,7 +89,7 @@ def main(font_file_name: str,
     print(symbols)
 
     font = ImageFont.truetype(font=font_file_name, size=char_size)
-    image = Image.new(mode='RGB', size=(size, size), color=color_background)
+    image = Image.new(mode=image_mode, size=(size, size), color=color_background)
     draw = ImageDraw.Draw(im=image)
 
     for i in range(16):
